Learn R Programming

binspp (version 0.2.3)

print.output_estintp: Text output describing the posterior distributions

Description

The summaries of the posterior distributions in the text form are provided.

Usage

# S3 method for output_estintp
print(x, ...)

Value

Text output summarizing the posterior distributions.

Arguments

x

list, output of the main function estintp().

...

further arguments passed from generic print function.

Details

The parameter estimates (sample medians from the empirical posterior distributions) and the corresponding credible intervals are printed.
Additionally, during the run of the MCMC chain the significance of the covariates in the list z_beta with respect to the current population of parent points is repeatedly tested. This function prints the median of the series of p-values obtained in this way for each covariate, together with the corresponding credible interval.

Examples

Run this code

library(spatstat)
# Prepare the dataset:
X <- trees_N4
x_left <- x_left_N4
x_right <- x_right_N4
y_bottom <- y_bottom_N4
y_top <- y_top_N4

z_beta <- list(refor = cov_refor, slope = cov_slope)
z_alpha <- list(tmi = cov_tmi, tdensity = cov_tdensity)
z_omega <- list(slope = cov_slope, reserv = cov_reserv)

# Determine the union of rectangles:
W <- owin(c(x_left[1], x_right[1]), c(y_bottom[1], y_top[1]))
if (length(x_left) >= 2) {
  for (i in 2:length(x_left)) {
    W2 <- owin(c(x_left[i], x_right[i]), c(y_bottom[i], y_top[i]))
    W <- union.owin(W, W2)
  }
}

# Dilated observation window:
W_dil <- dilation.owin(W, 100)


# Default parameters for prior distributions:
control <- list(NStep = 100, BurnIn = 20, SamplingFreq = 5)


# MCMC estimation:
Output <- estintp(X = X, control = control, x_left = x_left, x_right = x_right,
    y_bottom = y_bottom, y_top = y_top, W_dil = W_dil, z_beta = z_beta,
    z_alpha = z_alpha, z_omega = z_omega, verbose = FALSE)


# Text output
print(Output)

Run the code above in your browser using DataLab