powered by
Simulation of generalized Thomas process.
rgtp( kappa, omega, lambda, theta, win = owin(c(0, 1), c(0, 1)), nsim = 1, expand = 4 * omega, C = NULL )
A list(X, C), where X is Generalized Thomas process, and C is Process of cluster centers for Generalized Thomas process.
intensity of cluster centers.
standard deviation of normal distribution specifying the clusters spread.
parameter of generalised Poisson distribution controlling over or under dispersion.
parameter of generalised Poisson distribution controlling the mean number of points in a cluster.
window in which to simulate the pattern. An object in the spatstat.geom::owin() format of the spatstat package.
spatstat.geom::owin()
number of simulations.
the size of expansion of window to simulate the centers of clusters.
.
library(spatstat.geom) kappa = 10 omega = .1 lambda= .5 theta = 10 X = rgtp(kappa, omega, lambda, theta, win = owin(c(0, 1), c(0, 1))) plot(X$X) plot(X$C)
Run the code above in your browser using DataLab